@@ -293,4 +293,31 @@ const gchar* gexiv2_metadata_get_exif_tag_type (const gchar* tag) {
     return NULL;
 }
 
+GBytes* gexiv2_metadata_get_exif_tag_raw (GExiv2Metadata *self, const gchar* tag) {
+    g_return_val_if_fail(GEXIV2_IS_METADATA (self), NULL);
+    g_return_val_if_fail(tag != NULL, NULL);
+    g_return_val_if_fail(self->priv->image.get() != NULL, NULL);
+
+    Exiv2::ExifData &exif_data = self->priv->image->exifData();
+
+    try {
+        Exiv2::ExifData::iterator it = exif_data.findKey(Exiv2::ExifKey(tag));
+        while (it != exif_data.end() && it->count() == 0)
+            it++;
+
+        if (it != exif_data.end()) {
+            long size = it->size();
+            if( size > 0 ) {
+                gpointer data = g_malloc(size);
+                it->copy((Exiv2::byte*)data, Exiv2::invalidByteOrder);
+                return g_bytes_new_take(data, size);
+            }
+        }
+    } catch (Exiv2::Error& e) {
+        LOG_ERROR(e);
+    }
+
+    return NULL;
+}
+
 G_END_DECLS
