@@ -50,6 +50,8 @@ const gchar*	gexiv2_metadata_get_exif_tag_label	(const gchar* tag);
 const gchar*	gexiv2_metadata_get_exif_tag_description (const gchar* tag);
 const gchar*	gexiv2_metadata_get_exif_tag_type (const gchar* tag);
 
+GBytes*			gexiv2_metadata_get_exif_tag_raw	(GExiv2Metadata *self, const gchar* tag);
+
 /* private XMP functions */
 
 gboolean		gexiv2_metadata_clear_xmp_tag		(GExiv2Metadata *self, const gchar* tag);
@@ -66,6 +68,8 @@ const gchar*	gexiv2_metadata_get_xmp_tag_label		(const gchar* tag);
 const gchar*	gexiv2_metadata_get_xmp_tag_description	(const gchar* tag);
 const gchar*	gexiv2_metadata_get_xmp_tag_type	(const gchar* tag);
 
+GBytes*			gexiv2_metadata_get_xmp_tag_raw		(GExiv2Metadata *self, const gchar* tag);
+
 /* private IPTC functions */
 
 gboolean		gexiv2_metadata_clear_iptc_tag		(GExiv2Metadata *self, const gchar* tag);
@@ -80,6 +84,7 @@ const gchar*	gexiv2_metadata_get_iptc_tag_label	(const gchar* tag);
 const gchar*	gexiv2_metadata_get_iptc_tag_description	(const gchar* tag);
 const gchar*	gexiv2_metadata_get_iptc_tag_type	(const gchar* tag);
 
+GBytes*			gexiv2_metadata_get_iptc_tag_raw	(GExiv2Metadata *self, const gchar* tag);
 
 G_END_DECLS
 
