@@ -30,6 +30,22 @@ void gexiv2_metadata_clear_xmp(GExiv2Metadata *self) {
     self->priv->image->xmpData().clear();
 }
 
+gchar *gexiv2_metadata_generate_xmp_packet(GExiv2Metadata *self, 
+    GExiv2XmpFormatFlags xmp_format_flags, guint32 padding) {
+    g_return_val_if_fail(GEXIV2_IS_METADATA (self), NULL);
+    g_return_val_if_fail(self->priv->image.get() != NULL, NULL);
+    
+    Exiv2::XmpData &xmp_data = self->priv->image->xmpData();
+    try {
+        if (Exiv2::XmpParser::encode(self->priv->image->xmpPacket(), xmp_data, xmp_format_flags, padding) == 0)
+          return g_strdup(self->priv->image->xmpPacket().c_str());
+    } catch (Exiv2::Error& e) {
+        LOG_ERROR(e);
+    }
+    
+    return NULL;
+}
+
 gchar *gexiv2_metadata_get_xmp_packet(GExiv2Metadata *self) {
     g_return_val_if_fail(GEXIV2_IS_METADATA (self), NULL);
     g_return_val_if_fail(self->priv->image.get() != NULL, NULL);
@@ -156,6 +172,47 @@ gchar* gexiv2_metadata_get_xmp_tag_interpreted_string (GExiv2Metadata *self, con
     return NULL;
 }
 
+gboolean gexiv2_metadata_set_xmp_tag_struct (GExiv2Metadata *self, const gchar* tag, GExiv2StructureType type) {
+    g_return_val_if_fail(GEXIV2_IS_METADATA (self), FALSE);
+    g_return_val_if_fail(tag != NULL, FALSE);
+    g_return_val_if_fail(self->priv->image.get() != NULL, FALSE);
+
+    Exiv2::XmpTextValue tv("");
+    Exiv2::XmpData& xmp_data = self->priv->image->xmpData();
+
+    switch (type) {
+      case GEXIV2_STRUCTURE_XA_NONE:
+        tv.read("");  // Clear the value
+        tv.setXmpArrayType(Exiv2::XmpValue::xaNone);
+        break;
+      case GEXIV2_STRUCTURE_XA_ALT:
+        tv.read("");
+        tv.setXmpArrayType(Exiv2::XmpValue::xaAlt);
+        break;
+      case GEXIV2_STRUCTURE_XA_BAG:
+        tv.read("");
+        tv.setXmpArrayType(Exiv2::XmpValue::xaBag);
+        break;
+      case GEXIV2_STRUCTURE_XA_SEQ:
+        tv.read("");
+        tv.setXmpArrayType(Exiv2::XmpValue::xaSeq);
+        break;
+      default:
+        g_warning("Invalid structure type.");
+        return FALSE;
+        break;
+    }
+
+    try {
+        xmp_data.add(Exiv2::XmpKey(tag), &tv);
+        return TRUE;
+    } catch (Exiv2::Error& e) {
+        LOG_ERROR(e);
+    }
+    
+    return FALSE;
+}
+
 gboolean gexiv2_metadata_set_xmp_tag_string (GExiv2Metadata *self, const gchar* tag, 
     const gchar* value) {
     g_return_val_if_fail(GEXIV2_IS_METADATA (self), FALSE);
@@ -312,6 +369,33 @@ const gchar* gexiv2_metadata_get_xmp_tag_type (const gchar* tag) {
     return NULL;
 }
 
+GBytes* gexiv2_metadata_get_xmp_tag_raw (GExiv2Metadata *self, const gchar* tag) {
+    g_return_val_if_fail(GEXIV2_IS_METADATA (self), NULL);
+    g_return_val_if_fail(tag != NULL, NULL);
+    g_return_val_if_fail(self->priv->image.get() != NULL, NULL);
+
+    Exiv2::XmpData& xmp_data = self->priv->image->xmpData();
+
+    try {
+        Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
+
+        if (it != xmp_data.end()) {
+            long size = it->size();
+            if( size > 0 ) {
+                gpointer data = g_malloc(size);
+                it->copy((Exiv2::byte*)data, Exiv2::invalidByteOrder);
+                return g_bytes_new_take(data, size);
+            }
+        }
+    } catch (Exiv2::Error& e) {
+        LOG_ERROR(e);
+    }
+
+    return NULL;
+}
+
 gboolean gexiv2_metadata_register_xmp_namespace (const gchar* name, const gchar* prefix) {
     g_return_val_if_fail(name != NULL, FALSE);
     g_return_val_if_fail(prefix != NULL, FALSE);
